@@ -1,23 +1,33 @@
-# -*- coding: utf-8 -*-
-
+#-*- coding: utf-8 -*-
+from classytags.arguments import Argument
+from classytags.core import Tag, Options
 from django import template
-from django.template import loader, Context
-from django.forms import BooleanField
+from django.template.loader import render_to_string
+from django.template.context import RequestContext
+from django.utils.translation import gettext_lazy as _
 from feedback.utils import get_feedback_form
-from django.utils.translation import ugettext_lazy as _
+from feedback.settings import DEFAULT_FORM_KEY
+from django.forms.fields import BooleanField
+
 
 register = template.Library()
 
 
-@register.simple_tag
-def show_feedback(key='default'):
-    form = get_feedback_form(key)()
-    t = loader.select_template([
-        'feedback/%s/feedback.html' % key,
-        'feedback/feedback.html',
-    ])
-    output = t.render(Context(locals()))
-    return output
+class ShowFeedback(Tag):
+    name = 'show_feedback'
+    
+    options = Options(Argument('form_key', required=False, resolve=False))
+    
+    def render_tag(self, context, form_key):
+        form_key = form_key if form_key else DEFAULT_FORM_KEY
+        form = get_feedback_form(form_key)()
+        
+        return render_to_string([
+            'feedback/%s/feedback.html' % form_key,
+            'feedback/feedback.html',
+            ], {'form':form}, context_instance=RequestContext(context['request']))
+
+register.tag(ShowFeedback)
 
 
 @register.filter
